[![tests](https://github.com/andrehora/treeminer/actions/workflows/tests.yml/badge.svg)](https://github.com/andrehora/treeminer/actions/workflows/tests.yml)

# TreeMiner :deciduous_tree: :pick:

Multi-Language and Extensible Tool for Mining Git Repositories